@@ -2,14 +2,13 @@ package App::Midgen::Role::ExtraTests;
 
 use v5.10;
 use Moo::Role;
-requires qw( ppi_document debug format xtest _process_found_modules develop );
-
+#use MooX::Types::MooseLike::Base qw(:all);
 use Data::Printer { caller_info => 1, colored => 1, };
 
 # Load time and dependencies negate execution time
 # use namespace::clean -except => 'meta';
 
-our $VERSION = '0.25_05';
+our $VERSION = '0.22';
 
 
 
@@ -134,7 +133,7 @@ sub _xtests_includes {
 
 			if ( $self->xtest eq 'test_requires' ) {
 				$self->_process_found_modules( 'recommends', \@modules );
-			}
+			} 
 			elsif ( $self->develop && $self->xtest eq 'test_develop' ) {
 				$self->_process_found_modules( 'test_develop', \@modules );
 			}
@@ -167,7 +166,7 @@ App::Midgen::Roles::ExtraTests - used by L<App::Midgen>
 
 =head1 VERSION
 
-This document describes App::Midgen::Roles version: 0.25_05
+This document describes App::Midgen::Roles version: 0.22
 
 =head1 METHODS
 
