@@ -3,11 +3,12 @@ package App::Midgen::Roles;
 use v5.10;
 use Moo::Role;
 use MooX::Types::MooseLike::Base qw(:all);
+use Data::Printer { caller_info => 1, colored => 1, };
 
 # Load time and dependencies negate execution time
 # use namespace::clean -except => 'meta';
 
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 use Carp;
 
 #######
@@ -15,57 +16,37 @@ use Carp;
 #######
 
 has 'core' => (
-	is  => 'ro',
-	isa => sub {
-		croak "$_[0] this is not a Bool"
-			unless is_Bool( $_[0] );
-	},
-	default => sub {
-		0;
-	},
+	is       => 'ro',
+	isa      => Bool,
+	default  => sub {0},
 	required => 1,
 );
 
 has 'dual_life' => (
-	is  => 'ro',
-	isa => sub {
-		croak "$_[0] this is not a Bool"
-			unless is_Bool( $_[0] );
-	},
-	default => sub {
-		0;
-	},
+	is       => 'ro',
+	isa      => Bool,
+	default  => sub {0},
 	required => 1,
 );
 
 has 'debug' => (
-	is  => 'ro',
-	isa => sub {
-		croak "$_[0] this is not a Bool"
-			unless is_Bool( $_[0] );
-	},
-	default => sub {
-		0;
-	},
+	is       => 'ro',
+	isa      => Bool,
+	default  => sub {0},
 	required => 1,
 );
 
 has 'experimental' => (
-	is  => 'ro',
-	isa => sub {
-		croak "$_[0] this is not a Bool"
-			unless is_Bool( $_[0] );
-	},
-	default => sub {
-		0;
-	},
+	is       => 'ro',
+	isa      => Bool,
+	default  => sub {0},
 	required => 1,
 );
 
 has 'format' => (
 	is  => 'ro',
 	isa => sub {
-		my $format = { dsl => 1, mi => 1, build => 1, dzil => 1, dist => 1, cpanfile => 1, };
+		my $format = { dsl => 1, mi => 1, mb => 1, dzil => 1, dist => 1, cpanfile => 1, };
 		croak 'not a supported output format' unless defined $format->{ $_[0] };
 		return;
 	},
@@ -74,54 +55,66 @@ has 'format' => (
 );
 
 has 'verbose' => (
-	is  => 'ro',
-	isa => sub {
-		croak "$_[0] this is not a Bool"
-			unless is_Bool( $_[0] );
-	},
-	default => sub {
-		0;
-	},
+	is       => 'ro',
+	isa      => Int,
+	default  => sub {1},
 	required => 1,
 );
 
 has 'zero' => (
-	is  => 'ro',
-	isa => sub {
-		croak "$_[0] this is not a Bool"
-			unless is_Bool( $_[0] );
-	},
-	default => sub {
-		0;
-	},
+	is       => 'ro',
+	isa      => Bool,
+	default  => sub {0},
 	required => 1,
 );
 
+has 'quiet' => (
+	is       => 'ro',
+	isa      => Bool,
+	default  => sub {0},
+	required => 1,
+);
+
+around [qw( debug verbose )] => sub {
+	my $orig    = shift;
+	my $self    = shift;
+	my $content = $self->$orig(@_);
+
+	if ( $self->quiet == 1 && $self->experimental == 1 ) {
+		return 0;
+	} else {
+		return $content;
+	}
+};
+
 #######
-# some encapsulated attributes
+# some encapsulated -> attributes
 #######
 
 has 'numify' => (
+	is      => 'rw',
+	isa     => Bool,
+	default => sub {0},
+	lazy    => 1,
+);
+
+has 'distribution_name' => (
 	is   => 'rw',
-	isa  => Bool,
+	isa  => Str,
 	lazy => 1,
 );
 
-#has 'distribution_name' => (
-#	is   => 'rw',
-#	isa  => Str,
-#	lazy => 1,
-#);
-
-#has 'package_names' => (
-#	is   => 'rw',
-#	isa  => ArrayRef,
-#	lazy => 1,
-#);
+has 'package_names' => (
+	is      => 'rw',
+	isa     => ArrayRef,
+	default => sub { [] },
+	lazy    => 1,
+);
 
 #has 'package_requires' => (
 #	is   => 'rw',
 #	isa  => HashRef,
+#	default => sub { {} },
 #	lazy => 1,
 #);
 
@@ -158,51 +151,73 @@ has 'found_twins' => (
 	},
 );
 
-#has 'mcpan' => (
-#	is   => 'rw',
-#	isa  => InstanceOf [ 'MetaCPAN::API', ],
-#	lazy => 1,
-#	handles => [ qw( module new release ) ],
-#);
+has 'mcpan' => (
+	is      => 'rw',
+	isa     => InstanceOf [ 'MetaCPAN::API', ],
+	lazy    => 1,
+	builder => '_build_mcpan',
+	handles => [qw( module release )],
+);
 
-#has 'output' => (
-#	is   => 'rw',
-#	isa  => InstanceOf [ 'App::Midgen::Output', ],
-#	lazy => 1,
-#);
+sub _build_mcpan {
+	my $self = shift;
+	MetaCPAN::API->new();
+}
 
-#has 'scanner' => (
-#	is   => 'rw',
-#	isa  => InstanceOf [ 'Perl::PrereqScanner', ],
-#	lazy => 1,
-#);
+has 'output' => (
+	is      => 'rw',
+	isa     => InstanceOf [ 'App::Midgen::Output', ],
+	lazy    => 1,
+	builder => '_build_output',
 
-#has 'ppi_document' => (
-#	is   => 'rw',
-#	isa  => InstanceOf [ 'PPI::Document', ],
-#	lazy => 1,
-#);
+	#	handles => [ qw( ... ) ],
+);
+
+sub _build_output {
+	my $self = shift;
+	App::Midgen::Output->new();
+}
+
+has 'scanner' => (
+	is      => 'rw',
+	isa     => InstanceOf [ 'Perl::PrereqScanner', ],
+	lazy    => 1,
+	builder => '_build_scanner',
+	handles => [qw( scan_ppi_document )],
+);
+
+sub _build_scanner {
+	my $self = shift;
+	Perl::PrereqScanner->new();
+}
+
+has 'ppi_document' => (
+	is   => 'rw',
+	isa  => Object,
+	lazy => 1,
+);
 
 has 'xtest' => (
-	is => 'rw',
-	isa => Str,
-	lazy => 1,
+	is      => 'rw',
+	isa     => Str,
+	lazy    => 1,
 	default => sub {
 		'test_requires';
 	},
 );
 
 has 'develop' => (
-	is => 'ro',
-	isa => Bool,
-	lazy => 1,
+	is      => 'ro',
+	isa     => Bool,
+	lazy    => 1,
 	builder => '_develop',
 );
 
 sub _develop {
 	my $self = shift;
-#	return 'running builder';
-	if ( $self->{experimental} && $self->{format} eq 'cfile' ){
+
+	#	return 'running builder';
+	if ( $self->experimental && $self->format eq 'cpanfile' ) {
 		return 1;
 	} else {
 		return 0;
@@ -225,7 +240,7 @@ App::Midgen::Roles - Package Options and Attributes used by L<App::Midgen>
 
 =head1 VERSION
 
-This document describes App::Midgen::Roles version: 0.21
+This document describes App::Midgen::Roles version: 0.22
 
 =head1 METHODS
 
@@ -243,10 +258,16 @@ none as such, but we do have
 
 =item * experimental
 
+=item * quiet
+
 =item * format
 
 =item * verbose
 
+0 -> off
+1 -> default
+2 -> show files
+
 =item * zero
 
 =back
